Struct DragSource
pub struct DragSource { /* private fields */ }Available on crate feature
wayland and Linux only.Implementations
impl DragSource
impl DragSource
pub fn start_drag(
&self,
device: &DataDevice,
origin: &WlSurface,
icon: Option<&WlSurface>,
serial: u32,
)
pub fn start_drag( &self, device: &DataDevice, origin: &WlSurface, icon: Option<&WlSurface>, serial: u32, )
Start a normal drag and drop operation. This can be used for both intra-client DnD or inter-client Dnd. The drag is cancelled when the DragSource is dropped.
pub fn start_internal_drag(
device: &DataDevice,
origin: &WlSurface,
icon: Option<&WlSurface>,
serial: u32,
)
pub fn start_internal_drag( device: &DataDevice, origin: &WlSurface, icon: Option<&WlSurface>, serial: u32, )
Start an internal drag and drop operation. This will pass a NULL source, and the client is expected to handle data passing internally. Only Enter, Leave, & Motion events will be sent to the client
pub fn set_actions(&self, dnd_actions: DndAction)
pub fn set_actions(&self, dnd_actions: DndAction)
Set the actions that this drag source supports. This can only be done once, and must be done before the drag is started.
pub fn inner(&self) -> &WlDataSource
pub fn inner(&self) -> &WlDataSource
Retrieve a reference to the inner wl_data_source.